==> csbase-client-2.0.1-sources.jar: csbase/client/algorithms/parameters/InputURLParameterView.java <==
package csbase.client.algorithms.parameters;

import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;

import tecgraf.javautils.core.lng.LNG;
import csbase.client.desktop.RemoteTask;
import csbase.client.desktop.Task;
import csbase.client.util.StandardErrorDialogs;
import csbase.client.util.filechooser.ClientFileChooser;
import csbase.client.util.filechooser.ClientFileChooserSelectionMode;
import csbase.client.util.filechooser.ClientLocalFileChooserUtil;
import csbase.client.util.filechooser.ClientProjectFileChooserUtil;
import csbase.client.util.filechooser.ClientProjectFileChooserUtil.OperationResult;
import csbase.client.util.filechooser.ClientSGAFileChooserUtil;
import csbase.client.util.filechooser.util.ClientFileChooserUtils;
import csbase.logic.ClientFile;
import csbase.logic.ClientProjectFile;
import csbase.logic.ClientSGAFile;
import csbase.logic.ProjectFileType;
import csbase.logic.SGASet;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.InputURLParameter;
import csbase.logic.algorithms.parameters.URLProtocol;
import csbase.logic.algorithms.parameters.FileURLValue;
import csbase.remote.ClientRemoteLocator;
import csbase.remote.SGAServiceInterface;

/**
 * Viso do parmetro URL de entrada {@link InputURLParameter}.
 * 
 * @author Tecgraf
 */
public class InputURLParameterView extends URLParameterView {

  /**
   * Construtor.
   * 
   * @param parameter parmetro (No aceita {@code null}).
   * @param mode modo de visualizao. No aceita {@code null}.
   */
  public InputURLParameterView(InputURLParameter parameter, Mode mode) {
    super(parameter, mode);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public InputURLParameter getParameter() {
    return (InputURLParameter) super.getParameter();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  protected FileURLValue askForFile(URLProtocol fileProtocol, Object... args) {
    String fileType = getParameter().getFileType();
    List<String> fileTypes = new ArrayList<String>();
    if (fileType != null) {
      fileTypes.add(fileType);
    }
    ClientFileChooserSelectionMode selectionMode = getFileChooserMode();
    String title = getParameter().getLabel();
    switch (fileProtocol) {
      case PROJECT:
        return askForProjectFile(fileTypes, true, selectionMode, title);
      case LOCAL:
        return askForLocalFile(fileTypes, true, selectionMode, title);
      case SGA:
        String sgaName = (String) args[0];
        return askForSGAFile(fileTypes, true, selectionMode, title, sgaName);
    }
    return null;
  }

  /**
   * Abre um navegador de arquivos do projeto.
   * 
   * @param fileTypes os tipos de arquivo permitidos.
   * @param allowAll determina se a opo de escolher qualquer tipo de arquivo
   *        deve ser habilitada.
   * @param selectionMode o modo de seleo
   *        {@link ClientFileChooserSelectionMode}.
   * @param title o ttulo para a janela do navegador.
   * 
   * @return a URL do arquivo selecionado.
   */
  private FileURLValue askForProjectFile(List<String> fileTypes, boolean allowAll,
    ClientFileChooserSelectionMode selectionMode, String title) {
    switch (selectionMode) {
      case DIRECTORIES_ONLY:
        OperationResult dirResult =
          ClientProjectFileChooserUtil.browseSingleDirectoryInOpenMode(
            getWindow(), title, allowAll);
        if (dirResult != null) {
          ClientProjectFile dir = dirResult.getClientProjectFile();
          return getURLFromFile(URLProtocol.PROJECT, dir, null);
        }
        break;
      case FILES_ONLY:
        OperationResult fileResult =
          ClientProjectFileChooserUtil.browseSingleFileInOpenMode(getWindow(),
            fileTypes, title, allowAll);
        if (fileResult != null) {
          ClientFile file = fileResult.getClientProjectFile();
          return getURLFromFile(URLProtocol.PROJECT, file, null);
        }
        break;
    }
    return null;
  }

  /**
   * Abre um navegador de arquivos do cliente.
   * 
   * @param fileTypes os tipos de arquivo permitidos.
   * @param allowAll determina se a opo de escolher qualquer tipo de arquivo
   *        deve ser habilitada.
   * @param selectionMode o modo de seleo
   *        {@link ClientFileChooserSelectionMode}.
   * @param title o ttulo para a janela do navegador.
   * 
   * @return a URL do arquivo selecionado.
   */
  private FileURLValue askForLocalFile(List<String> fileTypes, boolean allowAll,
    ClientFileChooserSelectionMode selectionMode, String title) {
    switch (selectionMode) {
      case DIRECTORIES_ONLY:
        ClientFile localDir =
          ClientLocalFileChooserUtil.browseSingleDirectoryInOpenMode(
            getWindow(), title, allowAll, ClientFileChooserUtils
              .getLocalHomeDirectory());
        return getURLFromFile(URLProtocol.LOCAL, localDir, null);
      case FILES_ONLY:
        ClientFile localFile =
          ClientLocalFileChooserUtil.browseSingleFileInOpenMode(getWindow(),
            fileTypes, title, allowAll, ClientFileChooserUtils
              .getLocalHomeDirectory());
        return getURLFromFile(URLProtocol.LOCAL, localFile, null);
    }
    return null;
  }

  /**
   * Abre um navegador de arquivos do SGA.
   * 
   * @param fileTypes os tipos de arquivo permitidos.
   * @param allowAll determina se a opo de escolher qualquer tipo de arquivo
   *        deve ser habilitada.
   * @param selectionMode o modo de seleo
   *        {@link ClientFileChooserSelectionMode}.
   * @param title o ttulo para a janela do navegador.
   * @param sgaName nome do SGA.
   * 
   * @return a URL do arquivo selecionado.
   */
  private FileURLValue askForSGAFile(List<String> fileTypes, boolean allowAll,
    ClientFileChooserSelectionMode selectionMode, String title,
    final String sgaName) {
    if (sgaName == null) {
      return null;
    }

    final SGAServiceInterface sgaService = ClientRemoteLocator.sgaService;
    Task<Boolean> sgaIsAliveTask = new RemoteTask<Boolean>() {
      @Override
      protected void performTask() throws Exception {
        SGASet sga = sgaService.getSGASet(sgaName);
        setResult(sga.getAlive());
      }
    };
    boolean isAlive = false;
    String description =
      LNG.get(URLParameterView.class.getSimpleName() + ".sga_alive_task");
    if (sgaIsAliveTask.execute(getWindow(), title, description)) {
      isAlive = sgaIsAliveTask.getResult();
    }

    if (!isAlive) {
      String errorMessage =
        LNG.get(URLParameterView.class.getSimpleName() + ".sga_not_alive",
          new Object[] { sgaName });
      StandardErrorDialogs.showErrorDialog(getWindow(), errorMessage);
      return null;
    }

    ClientSGAFile root = new ClientSGAFile(sgaName, "/");
    switch (selectionMode) {
      case DIRECTORIES_ONLY:
        ClientSGAFile dir =
          ClientSGAFileChooserUtil.browseSingleDirectoryInOpenMode(getWindow(),
            title, fileTypes, allowAll, root);
        return getURLFromFile(URLProtocol.SGA, dir, sgaName);
      case FILES_ONLY:
        ClientSGAFile file =
          ClientSGAFileChooserUtil.browseSingleFileInOpenMode(getWindow(),
            title, fileTypes, allowAll, root);
        return getURLFromFile(URLProtocol.SGA, file, sgaName);
      default:
        return null;
    }
  }

  /**
   * Obtm a URL a partir de um arquivo.
   * 
   * @param fileProtocol o protocolo de acesso ao arquivo.
   * @param file o arquivo.
   * @param host o host da URL.
   * @return URL.
   */
  private FileURLValue getURLFromFile(URLProtocol fileProtocol, ClientFile file,
    String host) {
    if (file == null) {
      return null;
    }
    String type;
    if (file.isDirectory()) {
      type = ProjectFileType.DIRECTORY_TYPE;
    }
    else {
      type = file.getType();
    }
    return new FileURLValue(file.getStringPath(), type, fileProtocol, host);
  }

  /**
   * Obtm o modo do {@link ClientFileChooser} que ser utilizado para solicitar
   * os arquivos ao usurio.
   * 
   * @return modo arquivo ou diretrio.
   */
  private ClientFileChooserSelectionMode getFileChooserMode() {
    FileParameterMode parameterMode = getParameter().getMode();
    switch (parameterMode) {
      case REGULAR_FILE:
        return ClientFileChooserSelectionMode.FILES_ONLY;
      case DIRECTORY:
        return ClientFileChooserSelectionMode.DIRECTORIES_ONLY;
      default:
        String errorMessage =
          MessageFormat.format("O modo {0} no  vlido.", parameterMode);
        throw new IllegalStateException(errorMessage);
    }
  }

}

==> csbase-client-2.1.0-sources.jar: csbase/client/algorithms/parameters/InputURLParameterView.java <==
package csbase.client.algorithms.parameters;

import java.text.MessageFormat;
import java.util.LinkedList;
import java.util.List;

import csbase.client.desktop.RemoteTask;
import csbase.client.desktop.Task;
import csbase.client.util.StandardErrorDialogs;
import csbase.client.util.filechooser.ClientFileChooser;
import csbase.client.util.filechooser.ClientFileChooserSelectionMode;
import csbase.client.util.filechooser.ClientLocalFileChooserUtil;
import csbase.client.util.filechooser.ClientProjectFileChooserUtil;
import csbase.client.util.filechooser.ClientProjectFileChooserUtil.OperationResult;
import csbase.client.util.filechooser.ClientSGAFileChooserUtil;
import csbase.client.util.filechooser.util.ClientFileChooserUtils;
import csbase.logic.ClientFile;
import csbase.logic.ClientProjectFile;
import csbase.logic.ClientSGAFile;
import csbase.logic.SGASet;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.InputURLParameter;
import csbase.logic.algorithms.parameters.URLProtocol;
import csbase.logic.algorithms.parameters.FileURLValue;
import csbase.remote.ClientRemoteLocator;
import csbase.remote.SGAServiceInterface;
import tecgraf.javautils.core.lng.LNG;

/**
 * Viso do parmetro URL de entrada {@link InputURLParameter}.
 * 
 * @author Tecgraf
 */
public class InputURLParameterView extends URLParameterView {

  /**
   * Construtor.
   * 
   * @param parameter parmetro (No aceita {@code null}).
   * @param mode modo de visualizao. No aceita {@code null}.
   */
  public InputURLParameterView(InputURLParameter parameter, Mode mode) {
    super(parameter, mode);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public InputURLParameter getParameter() {
    return (InputURLParameter) super.getParameter();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  protected FileURLValue askForFile(URLProtocol fileProtocol, Object... args) {
    String fileType = getParameter().getFileType();
    ClientFileChooserSelectionMode selectionMode = getFileChooserMode();
    String title = getParameter().getLabel();
    switch (fileProtocol) {
      case PROJECT:
        return askForProjectFile(fileType, selectionMode, title);
      case LOCAL:
        return askForLocalFile(fileType, selectionMode, title);
      case SGA:
        String sgaName = (String) args[0];
        return askForSGAFile(fileType, selectionMode, title, sgaName);
    }
    return null;
  }

  /**
   * Abre um navegador de arquivos do projeto.
   * 
   * @param fileType o tipo de arquivo permitido.
   * @param selectionMode o modo de seleo
   *        {@link ClientFileChooserSelectionMode}.
   * @param title o ttulo para a janela do navegador.
   * 
   * @return a URL do arquivo selecionado.
   */
  private FileURLValue askForProjectFile(String fileType,
    ClientFileChooserSelectionMode selectionMode, String title) {
    OperationResult result =
      ClientProjectFileChooserUtil.browseSingleInOpenMode(getWindow(), title, 
        selectionMode, true, fileType); 
    if (result != null) {
      ClientProjectFile dir = result.getClientProjectFile();
      return getURLFromFile(URLProtocol.PROJECT, dir, null);
    }
    return null;
  }

  /**
   * Abre um navegador de arquivos do cliente.
   * 
   * @param fileType o tipo de arquivo permitido.
   * @param selectionMode o modo de seleo
   *        {@link ClientFileChooserSelectionMode}.
   * @param title o ttulo para a janela do navegador.
   * 
   * @return a URL do arquivo selecionado.
   */
  private FileURLValue askForLocalFile(String fileType,
    ClientFileChooserSelectionMode selectionMode, String title) {
    List<String> fileTypes = new LinkedList<String>();
    if (fileType != null) {
      fileTypes.add(fileType);
    }
    switch (selectionMode) {
      case DIRECTORIES_ONLY:
        ClientFile localDir =
          ClientLocalFileChooserUtil.browseSingleDirectoryInOpenMode(
            getWindow(), fileTypes,  title, true, ClientFileChooserUtils
              .getLocalHomeDirectory());
        return getURLFromFile(URLProtocol.LOCAL, localDir, null);
      case FILES_ONLY:
        ClientFile localFile =
          ClientLocalFileChooserUtil.browseSingleFileInOpenMode(getWindow(),
            fileTypes, title, true, ClientFileChooserUtils
              .getLocalHomeDirectory());
        return getURLFromFile(URLProtocol.LOCAL, localFile, null);
    }
    return null;
  }

  /**
   * Abre um navegador de arquivos do SGA.
   * 
   * @param fileType o tipo de arquivo permitido.
   * @param selectionMode o modo de seleo
   *        {@link ClientFileChooserSelectionMode}.
   * @param title o ttulo para a janela do navegador.
   * @param sgaName nome do SGA.
   * 
   * @return a URL do arquivo selecionado.
   */
  private FileURLValue askForSGAFile(String fileType,
    ClientFileChooserSelectionMode selectionMode, String title,
    final String sgaName) {
    if (sgaName == null) {
      return null;
    }

    final SGAServiceInterface sgaService = ClientRemoteLocator.sgaService;
    Task<Boolean> sgaIsAliveTask = new RemoteTask<Boolean>() {
      @Override
      protected void performTask() throws Exception {
        SGASet sga = sgaService.getSGASet(sgaName);
        setResult(sga.getAlive());
      }
    };
    boolean isAlive = false;
    String description =
      LNG.get(URLParameterView.class.getSimpleName() + ".sga_alive_task");
    if (sgaIsAliveTask.execute(getWindow(), title, description)) {
      isAlive = sgaIsAliveTask.getResult();
    }

    if (!isAlive) {
      String errorMessage =
        LNG.get(URLParameterView.class.getSimpleName() + ".sga_not_alive",
          new Object[] { sgaName });
      StandardErrorDialogs.showErrorDialog(getWindow(), errorMessage);
      return null;
    }
    List<String> fileTypes = new LinkedList<String>();
    if (fileType != null) {
      fileTypes.add(fileType);
    }
    ClientSGAFile root = new ClientSGAFile(sgaName, "/");
    switch (selectionMode) {
      case DIRECTORIES_ONLY:
        ClientSGAFile dir =
          ClientSGAFileChooserUtil.browseSingleDirectoryInOpenMode(getWindow(),
            fileTypes, title, true, root);
        return getURLFromFile(URLProtocol.SGA, dir, sgaName);
      case FILES_ONLY:
        ClientSGAFile file =
          ClientSGAFileChooserUtil.browseSingleFileInOpenMode(getWindow(),
            fileTypes, title, true, root);
        return getURLFromFile(URLProtocol.SGA, file, sgaName);
      default:
        return null;
    }
  }

  /**
   * Obtm a URL a partir de um arquivo.
   * 
   * @param fileProtocol o protocolo de acesso ao arquivo.
   * @param file o arquivo.
   * @param host o host da URL.
   * @return URL.
   */
  private FileURLValue getURLFromFile(URLProtocol fileProtocol, ClientFile file,
    String host) {
    if (file == null) {
      return null;
    }
    String type = file.getType();
    return new FileURLValue(file.getStringPath(), type, fileProtocol, host);
  }

  /**
   * Obtm o modo do {@link ClientFileChooser} que ser utilizado para solicitar
   * os arquivos ao usurio.
   * 
   * @return modo arquivo ou diretrio.
   */
  private ClientFileChooserSelectionMode getFileChooserMode() {
    FileParameterMode parameterMode = getParameter().getMode();
    switch (parameterMode) {
      case REGULAR_FILE:
        return ClientFileChooserSelectionMode.FILES_ONLY;
      case DIRECTORY:
        return ClientFileChooserSelectionMode.DIRECTORIES_ONLY;
      default:
        String errorMessage =
          MessageFormat.format("O modo {0} no  vlido.", parameterMode);
        throw new IllegalStateException(errorMessage);
    }
  }

}
